==> haskell-wl-pprint-extras-3.5.0.5-501-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-7BZagHcD10f4u3uYh96mpB
key:                  wl-pprint-extras-3.5.0.5-7BZagHcD10f4u3uYh96mpB
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  1d023746ea6b2d2160c72b7ba870033e
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-extras-3.5.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-7BZagHcD10f4u3uYh96mpB
depends:
    base-4.17.2.1 containers-0.6.7
    semigroupoids-6.0.1-3IusD49fh3L4503jEduMVH text-2.0.2
    utf8-string-1.0.2-4puy9i6JhHg6bynwSjfiUA

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-502-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-JLLoMOpdRWaEZIe5lsVEUg
key:                  wl-pprint-extras-3.5.0.5-JLLoMOpdRWaEZIe5lsVEUg
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  3e736019bcaf91d9afbaab29298c3e34
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-extras-3.5.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-JLLoMOpdRWaEZIe5lsVEUg
depends:
    base-4.17.2.1 containers-0.6.7
    semigroupoids-6.0.1-GnTPBdhtPP6J9cQ7FqPmVK text-2.0.2
    utf8-string-1.0.2-LQzUWC2hIN17FDKHsw4I2c

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
